% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

clear all;


%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = 0.1;     % Vmf_SDH
T = 25;            % Temperature

% (2.) Setting initial values
xo(1) = 5e-3;       % Succinate (M)
xo(2) = 5e-4;       % coQ (M)
xo(3) = 5e-4;       % coQH2 (M)
xo(4) = 3e-3;       % Fumarate (M)
xo(5) = 1e-3;       % Oxaloacetate (M)
xo(6) = 1e-7;       % [H] (M)
xo(7) = 1e-3;       % [Mg] (M)
xo(8) = 150e-3;     % [K] (M)

% (3.) Running for 15-second time course
[t,x] = ode15s(@SDH,[0 15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,4)*1e3,'k:');
set(p,'linewidth',1.5);
text(1,4.75,'Succinate','Fontsize',14);
text(1,3.25,'Fumarate','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,x(:,2)*1e3,'k-',t,x(:,3)*1e3,'k:');
set(p,'linewidth',1.5);
text(5,.6,'coQ','Fontsize',14);
text(5,.4,'coQH2','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,6)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);


Table = array2table([t,x],'variableNames',{'Time','BISEN_Suc','BISEN_coq','BISEN_coqH2','BISEN_Fum','Oxa','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'SDHBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'SDHisenOutput.csv';
writetable(Table,filename);
%%
